@@ -36,7 +36,7 @@ use Devel::StackTrace;
 use CPAN::Version;
 use if CPAN::Version->vgt($^V,  'v5.10.1'), experimental => 'switch';
 
-our $VERSION='0.0.3';
+our $VERSION='0.0.4';
 
 # debug flag
 my $debug=0;
@@ -85,7 +85,7 @@ sub spawn {
 
 =over 4
 
-=item DEBUG
+=item debug
 
 Enable/Disable debug mode if passing an argument. Return debug mode if no argument.
 
@@ -411,6 +411,15 @@ sub prompt_str {
 }
 
 #获取设备sysname
+
+=item get_sysname
+
+Return device host name.
+
+=back
+
+=cut
+
 sub get_sysname {
 	my $self=shift;
 	my $prompt_str = $self->prompt_str;
@@ -441,6 +450,20 @@ sub view{
 
 
 #登录到网络设备的用户视图
+
+=item login
+
+	$obj->login($host, $username, $password, $ssh )
+
+$ssh: 1  using ssh
+	  0  use telnet
+
+Login to device.
+
+=back
+
+=cut
+
 sub login {
 	my ( $self, $host, $username, $password, $ssh ) = @_;
 
@@ -524,6 +547,17 @@ sub login {
 }
 
 #退出登录
+
+=item logout
+
+$obj->logout
+
+Logout from device.
+
+=back
+
+=cut
+
 sub logout {
 	my $self   = shift;
 	my $state=&get_state($self);
@@ -558,6 +592,15 @@ sub logout {
 }
 
 #获取设备型号
+
+=item get_device_type
+
+Get device type
+
+=back
+
+=cut
+
 sub get_device_type {
 	my $self = shift;
 	my $ret  = undef;
@@ -588,6 +631,15 @@ sub get_device_type {
 }
 
 #返回设备的配置文件名
+
+=item get_config_filename
+
+Get configuration filename.
+
+=back
+
+=cut
+
 sub get_config_filename{
 	my $self = shift;
 
@@ -599,6 +651,15 @@ sub get_config_filename{
 }
 
 #将一个指定的文件备份到指定的ftp服务器
+
+=item backup_config
+
+backup config file to a ftp server.
+
+=back
+
+=cut
+
 sub backup_config{
 	my $self = shift;
 
@@ -668,6 +729,15 @@ sub change_password {
 }
 
 # get software version
+
+=item get_version
+
+Get software version string.
+
+=back
+
+=cut
+
 sub get_version{
 	my $self = shift;
 
@@ -688,6 +758,15 @@ sub get_version{
 }
 
 # execute command
+
+=item exec_cmd
+
+Execute command and get output.
+
+=back
+
+=cut
+
 sub exec_cmd {
 	my $self   = shift;
 	my $cmd = shift;
@@ -705,6 +784,15 @@ sub exec_cmd {
 }
 
 # enter system view
+
+=item enter_system
+
+Enter system mode.
+
+=back
+
+=cut
+
 sub enter_system{
 	my $self = shift;
 
@@ -722,6 +810,15 @@ sub enter_system{
 }
 
 # quit system view
+
+=item quit_system
+
+Quit system mode.
+
+=back
+
+=cut
+
 sub quit_system{
 	my $self = shift;
 
@@ -734,6 +831,13 @@ sub quit_system{
 }
 
 # save config
+
+=item save configration file
+
+=back
+
+=cut
+
 sub save_config{
 	my $self = shift;
 	
@@ -779,6 +883,15 @@ sub save_config{
 }
 
 # get arp list
+
+=item get_arp
+
+Get arp list.
+
+=back
+
+=cut
+
 sub get_arp{
 	my $self = shift;
 	my $state=&get_state($self);
@@ -799,6 +912,15 @@ sub get_arp{
 }
 
 #读取mac列表
+
+=item get_maclist
+
+Get mac list.
+
+=back
+
+=cut
+
 sub get_maclist{
 	my $self = shift;
 	$self->enter_system;
@@ -812,6 +934,15 @@ sub get_maclist{
 }
 
 #读取配置文件
+
+=item get_config
+
+Get configration file.
+
+=back
+
+=cut
+
 sub get_config{
 	my $self=shift;
 	my $old_timeout=$self->timeout;
@@ -921,6 +1052,15 @@ sub get_int_mac{
 }
 
 # set device name
+
+=item set_sysname
+
+Set the name of the device.
+
+=back
+
+=cut
+
 sub set_sysname{
 	my ($self, $sysname) = @_;
 	return unless $self->enter_system;
